from PyObjCTools.TestSupport import TestCase

import UniformTypeIdentifiers


class TestUTAdditions(TestCase):
    def test_methods(self):
        UniformTypeIdentifiers.NSString.stringByAppendingPathComponent_conformingToType_



from PyObjCTools.TestSupport import TestCase

import UniformTypeIdentifiers


class TestUTType(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.isDynamic)
        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.isDeclared)
        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.isPublicType)

        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.conformsToType_)
        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.isSupertypeOfType_)
        self.assertResultIsBOOL(UniformTypeIdentifiers.UTType.isSubtypeOfType_)



# This file is generated by objective.metadata
#
# Last update: Fri Jun 24 10:20:35 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$UTTagClassFilenameExtension$UTTagClassMIMEType$UTType3DContent$UTTypeAIFF$UTTypeARReferenceObject$UTTypeAVI$UTTypeAliasFile$UTTypeAppleArchive$UTTypeAppleProtectedMPEG4Audio$UTTypeAppleProtectedMPEG4Video$UTTypeAppleScript$UTTypeApplication$UTTypeApplicationBundle$UTTypeApplicationExtension$UTTypeArchive$UTTypeAssemblyLanguageSource$UTTypeAudio$UTTypeAudiovisualContent$UTTypeBMP$UTTypeBZ2$UTTypeBinaryPropertyList$UTTypeBookmark$UTTypeBundle$UTTypeCHeader$UTTypeCPlusPlusHeader$UTTypeCPlusPlusSource$UTTypeCSource$UTTypeCalendarEvent$UTTypeCommaSeparatedText$UTTypeCompositeContent$UTTypeContact$UTTypeContent$UTTypeData$UTTypeDatabase$UTTypeDelimitedText$UTTypeDirectory$UTTypeDiskImage$UTTypeEPUB$UTTypeEXE$UTTypeEmailMessage$UTTypeExecutable$UTTypeFileURL$UTTypeFlatRTFD$UTTypeFolder$UTTypeFont$UTTypeFramework$UTTypeGIF$UTTypeGZIP$UTTypeHEIC$UTTypeHEIF$UTTypeHTML$UTTypeICNS$UTTypeICO$UTTypeImage$UTTypeInternetLocation$UTTypeInternetShortcut$UTTypeItem$UTTypeJPEG$UTTypeJSON$UTTypeJavaScript$UTTypeLivePhoto$UTTypeLog$UTTypeM3UPlaylist$UTTypeMIDI$UTTypeMP3$UTTypeMPEG$UTTypeMPEG2TransportStream$UTTypeMPEG2Video$UTTypeMPEG4Audio$UTTypeMPEG4Movie$UTTypeMakefile$UTTypeMessage$UTTypeMountPoint$UTTypeMovie$UTTypeOSAScript$UTTypeOSAScriptBundle$UTTypeObjectiveCPlusPlusSource$UTTypeObjectiveCSource$UTTypePDF$UTTypePHPScript$UTTypePKCS12$UTTypePNG$UTTypePackage$UTTypePerlScript$UTTypePlainText$UTTypePlaylist$UTTypePluginBundle$UTTypePresentation$UTTypePropertyList$UTTypePythonScript$UTTypeQuickLookGenerator$UTTypeQuickTimeMovie$UTTypeRAWImage$UTTypeRTF$UTTypeRTFD$UTTypeRealityFile$UTTypeResolvable$UTTypeRubyScript$UTTypeSVG$UTTypeSceneKitScene$UTTypeScript$UTTypeShellScript$UTTypeSourceCode$UTTypeSpotlightImporter$UTTypeSpreadsheet$UTTypeSwiftSource$UTTypeSymbolicLink$UTTypeSystemPreferencesPane$UTTypeTIFF$UTTypeTabSeparatedText$UTTypeText$UTTypeToDoItem$UTTypeURL$UTTypeURLBookmarkData$UTTypeUSD$UTTypeUSDZ$UTTypeUTF16ExternalPlainText$UTTypeUTF16PlainText$UTTypeUTF8PlainText$UTTypeUTF8TabSeparatedText$UTTypeUnixExecutable$UTTypeVCard$UTTypeVideo$UTTypeVolume$UTTypeWAV$UTTypeWebArchive$UTTypeWebP$UTTypeX509Certificate$UTTypeXML$UTTypeXMLPropertyList$UTTypeXPCService$UTTypeYAML$UTTypeZIP$"""
enums = """$$"""
misc.update({})
misc.update({})
misc.update({})
aliases = {"UT_AVAILABLE_END": "API_AVAILABLE_END"}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSItemProvider",
        b"initWithContentsOfURL:contentType:openInPlace:coordinated:visibility:",
        {"arguments": {4: {"type": b"Z"}, 5: {"type": b"Z"}}},
    )
    r(
        b"NSItemProvider",
        b"loadDataRepresentationForContentType:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"NSItemProvider",
        b"loadFileRepresentationForContentType:openInPlace:completionHandler:",
        {
            "arguments": {
                3: {"type": b"Z"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"Z"},
                            3: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"NSItemProvider",
        b"registerDataRepresentationForContentType:visibility:loadHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@?"}},
                    }
                }
            }
        },
    )
    r(
        b"NSItemProvider",
        b"registerFileRepresentationForContentType:visibility:openInPlace:loadHandler:",
        {
            "arguments": {
                4: {"type": b"Z"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@?"}},
                    }
                },
            }
        },
    )
    r(b"UTType", b"conformsToType:", {"retval": {"type": b"Z"}})
    r(b"UTType", b"isDeclared", {"retval": {"type": b"Z"}})
    r(b"UTType", b"isDynamic", {"retval": {"type": b"Z"}})
    r(b"UTType", b"isPublicType", {"retval": {"type": b"Z"}})
    r(b"UTType", b"isSubtypeOfType:", {"retval": {"type": b"Z"}})
    r(b"UTType", b"isSupertypeOfType:", {"retval": {"type": b"Z"}})
    r(b"null", b"conformsToType:", {"retval": {"type": b"Z"}})
    r(b"null", b"isSubtypeOfType:", {"retval": {"type": b"Z"}})
    r(b"null", b"isSupertypeOfType:", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase

import UniformTypeIdentifiers


class TestUTTagClass(TestCase):
    def test_constants(self):
        self.assertIsInstance(UniformTypeIdentifiers.UTTagClassFilenameExtension, str)
        self.assertIsInstance(UniformTypeIdentifiers.UTTagClassMIMEType, str)



from PyObjCTools.TestSupport import TestCase, min_os_level

import UniformTypeIdentifiers


class TestUTCoreTypes(TestCase):
    def test_constants(self):
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeContent, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCompositeContent, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeDiskImage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeData, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeDirectory, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeResolvable, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSymbolicLink, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeExecutable, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMountPoint, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAliasFile, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeURLBookmarkData, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeURL, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeFileURL, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePlainText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUTF8PlainText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUTF16ExternalPlainText,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUTF16PlainText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeDelimitedText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCommaSeparatedText,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeTabSeparatedText, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUTF8TabSeparatedText,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeRTF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeHTML, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeXML, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeYAML, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSourceCode, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAssemblyLanguageSource,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCSource, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeObjectiveCSource, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSwiftSource, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCPlusPlusSource, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeObjectiveCPlusPlusSource,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCHeader, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCPlusPlusHeader, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAppleScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeOSAScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeOSAScriptBundle, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeJavaScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeShellScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePerlScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePythonScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeRubyScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePHPScript, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeJSON, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePropertyList, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeXMLPropertyList, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeBinaryPropertyList,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePDF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeRTFD, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeFlatRTFD, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeWebArchive, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeImage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeJPEG, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeTIFF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeGIF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePNG, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeICNS, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeBMP, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeICO, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeRAWImage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSVG, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeLivePhoto, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeHEIF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeHEIC, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeWebP, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTType3DContent, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUSD, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUSDZ, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeRealityFile, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSceneKitScene, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeARReferenceObject,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAudiovisualContent,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMovie, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeVideo, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAudio, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeQuickTimeMovie, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMPEG, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMPEG2Video, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMPEG2TransportStream,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMP3, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMPEG4Movie, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMPEG4Audio, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAppleProtectedMPEG4Audio,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAppleProtectedMPEG4Video,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAVI, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeAIFF, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeWAV, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMIDI, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePlaylist, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeM3UPlaylist, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeFolder, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeVolume, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePackage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeBundle, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePluginBundle, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSpotlightImporter,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeQuickLookGenerator,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeXPCService, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeFramework, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeApplication, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeApplicationBundle,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeApplicationExtension,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeUnixExecutable, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeEXE, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSystemPreferencesPane,
            UniformTypeIdentifiers.UTType,
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeArchive, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeGZIP, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeBZ2, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeZIP, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeSpreadsheet, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePresentation, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeDatabase, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMessage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeContact, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeVCard, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeToDoItem, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeCalendarEvent, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeEmailMessage, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeInternetLocation, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeInternetShortcut, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeFont, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeBookmark, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypePKCS12, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeX509Certificate, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeEPUB, UniformTypeIdentifiers.UTType
        )
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeLog, UniformTypeIdentifiers.UTType
        )

    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertIsInstance(
            UniformTypeIdentifiers.UTTypeMakefile, UniformTypeIdentifiers.UTType
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import UniformTypeIdentifiers


class TestNSItemProvider_UTType(TestCase):
    @min_os_level("13.0")
    def test_methods(self):
        self.assertArgIsBOOL(
            UniformTypeIdentifiers.NSItemProvider.initWithContentsOfURL_contentType_openInPlace_coordinated_visibility_,
            2,
        )
        self.assertArgIsBOOL(
            UniformTypeIdentifiers.NSItemProvider.initWithContentsOfURL_contentType_openInPlace_coordinated_visibility_,
            3,
        )

        self.assertArgIsBlock(
            UniformTypeIdentifiers.NSItemProvider.registerDataRepresentationForContentType_visibility_loadHandler_,
            2,
            b"@@?",  # XXX
        )

        self.assertArgIsBlock(
            UniformTypeIdentifiers.NSItemProvider.loadDataRepresentationForContentType_completionHandler_,
            1,
            b"v@@",
        )

        self.assertArgIsBOOL(
            UniformTypeIdentifiers.NSItemProvider.loadFileRepresentationForContentType_openInPlace_completionHandler_,
            1,
        )
        self.assertArgIsBlock(
            UniformTypeIdentifiers.NSItemProvider.loadFileRepresentationForContentType_openInPlace_completionHandler_,
            2,
            b"v@Z@",
        )
